==> ksy-metaplex-js-one-4.12.19.tgz: package/src/actions/shared/mint.ts <==
import { Connection, Keypair, PublicKey } from '@solana/web3.js';
import {
  ASSOCIATED_TOKEN_PROGRAM_ID,
  MintLayout,
  Token,
  TOKEN_PROGRAM_ID,
} from '@solana/spl-token';
import { CreateAssociatedTokenAccount, CreateMint, MintTo } from '../../transactions';
import { Transaction } from '@metaplex-foundation/mpl-core';
import { Wallet } from 'src/wallet';
import {WalletContextState} from '@solana/wallet-adapter-react' //ksy

interface MintTxs {
  mint: Keypair;
  // recipient ATA
  recipient: PublicKey;
  createMintTx: Transaction;
  createAssociatedTokenAccountTx: Transaction;
  mintToTx: Transaction;
}

export async function prepareTokenAccountAndMintTxs(
  connection: Connection,
  owner: PublicKey,
  wallet: Wallet,
  wallets: WalletContextState, //ksy
  feePayer?: PublicKey // MrChaos
): Promise<MintTxs> {

  console.log('prepareTokenAccountAndMintTxs 확인==', wallet.wallet.adapter.feePayer, ', wallet==', wallet, ', wallets==', wallets, ', connection==', connection);

  const mint = Keypair.generate();
  const mintRent = await connection.getMinimumBalanceForRentExemption(MintLayout.span);
  const createMintTx = new CreateMint(
    { feePayer: wallet.wallet.adapter.feePayer ?? owner}, // MrChaos
    {
      newAccountPubkey: mint.publicKey,
      lamports: mintRent,
    },
  );

  const recipient = await Token.getAssociatedTokenAddress(
    ASSOCIATED_TOKEN_PROGRAM_ID,
    TOKEN_PROGRAM_ID,
    mint.publicKey,
    owner,
  );

  const createAssociatedTokenAccountTx = new CreateAssociatedTokenAccount(
    { feePayer: wallet.wallet.adapter.feePayer },
    {
      associatedTokenAddress: recipient,
      splTokenMintAddress: mint.publicKey,
    },
  );

  const mintToTx = new MintTo(
    { feePayer: wallet.wallet.adapter.feePayer },
    {
      mint: mint.publicKey,
      dest: recipient,
      amount: 1,
    },
  );

  return { mint, createMintTx, createAssociatedTokenAccountTx, mintToTx, recipient };
}

==> ksy-metaplex-js-one-4.12.20.tgz: package/src/actions/shared/mint.ts <==
import { Connection, Keypair, PublicKey } from '@solana/web3.js';
import {
  ASSOCIATED_TOKEN_PROGRAM_ID,
  MintLayout,
  Token,
  TOKEN_PROGRAM_ID,
} from '@solana/spl-token';
import { CreateAssociatedTokenAccount, CreateMint, MintTo } from '../../transactions';
import { Transaction } from '@metaplex-foundation/mpl-core';
import { Wallet } from 'src/wallet';
//import {WalletContextState} from '@solana/wallet-adapter-react' //ksy

interface MintTxs {
  mint: Keypair;
  // recipient ATA
  recipient: PublicKey;
  createMintTx: Transaction;
  createAssociatedTokenAccountTx: Transaction;
  mintToTx: Transaction;
}

export async function prepareTokenAccountAndMintTxs(
  connection: Connection,
  owner: PublicKey,
  wallet: Wallet,
  //wallets: WalletContextState, //ksy
  feePayer?: PublicKey // MrChaos
): Promise<MintTxs> {

  console.log('[prepareTokenAccountAndMintTxs 확인] wallet.wallet.adapter.feePayer==', wallet.wallet.adapter.feePayer,
   ', owner==', owner, ', wallet==', wallet, ', connection==', connection);

  const mint = Keypair.generate();
  const mintRent = await connection.getMinimumBalanceForRentExemption(MintLayout.span);
  const createMintTx = new CreateMint(
    { feePayer: wallet.wallet.adapter.feePayer ?? owner}, // MrChaos
    {
      newAccountPubkey: mint.publicKey,
      lamports: mintRent,
    },
  );

  const recipient = await Token.getAssociatedTokenAddress(
    ASSOCIATED_TOKEN_PROGRAM_ID,
    TOKEN_PROGRAM_ID,
    mint.publicKey,
    owner,
  );

  const createAssociatedTokenAccountTx = new CreateAssociatedTokenAccount(
    { feePayer: wallet.wallet.adapter.feePayer ?? owner },
    {
      associatedTokenAddress: recipient,
      splTokenMintAddress: mint.publicKey,
    },
  );

  const mintToTx = new MintTo(
    { feePayer: wallet.wallet.adapter.feePayer ?? owner },
    {
      mint: mint.publicKey,
      dest: recipient,
      amount: 1,
    },
  );

  return { mint, createMintTx, createAssociatedTokenAccountTx, mintToTx, recipient };
}
